==> owncloud_6.0.4~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/contacts/l10n/es.php <==
<?php $TRANSLATIONS = array(
"Contacts" => "Contactos",
"Save" => "Guardar",
"Uploading..." => "Subiendo...",
"Importing..." => "Importando...",
"Preparing..." => "Preparando...",
"Imported {count} of {total} contacts" => "Importados {count} de un total de {total} contactos",
"Imported {imported} contacts. {failed} failed." => "{imported} contactos importados. Han fallado {failed}.",
"An address book called {name} already exists" => "Ya existe una libreta de contactos llamada {name}",
"Failed adding address book: {error}" => "Hubo un fallo al agregar la libreta de contactos: {error}",
"Failed loading address books: {error}" => "Se produjo un error al cargar las libretas de contactos: {error}",
"Indexing contacts" => "Indexando contactos",
"Unrecoverable error loading address books: {msg}" => "Error irrecuperable mientras se cargaban las libretas de contactos: {msg}",
"Error." => "Error.",
"Add to..." => "Añadir a...",
"Remove from..." => "Eliminar de...",
"Add group..." => "Añadir grupo...",
"Invalid URL: \"{url}\"" => "URL no válida: \"{url}\"",
"There was an error opening a mail composer." => "Hubo un error mientras se abría el compositor de correo electrónico.",
"Invalid email: \"{url}\"" => "Dirección de correo inválida: \"{url}\"",
"Merge failed. Cannot find contact: {id}" => "Error en la combinación. No se puede encontrar contacto: {id}",
"Merge failed." => "Error en la combinación.",
"Merge failed. Error saving contact." => "Combinación fallida. Error guardando el contacto.",
"Select photo" => "Seleccionar una foto",
"Network or server error. Please inform administrator." => "Error en la red o en el servidor. Por favor, informe al administrador.",
"Error adding to group." => "Error añadiendo al grupo.",
"Error removing from group." => "Error eliminando del grupo.",
"Error setting {name} as favorite." => "Error configurando {name} como favorito.",
"Merge contacts" => "Combinar contactos",
"Cancel" => "Cancelar",
"Add group" => "Añadir grupo",
"OK" => "Aceptar",
"Could not find contact: {id}" => "No se puede encontrar el contacto: {id}",
"No files selected for upload." => "No se seleccionaron archivos para subir.",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "El fichero que quieres subir excede el tamaño máximo permitido en este servidor.",
"Edit profile picture" => "Editar imagen de perfil.",
"Crop photo" => "Recortar imagen",
"Is this correct?" => "¿Es esto correcto?",
"Error parsing date: {date}" => "Error al analizar la fecha: {date}",
"# groups" => "# grupos",
"Error parsing birthday {bday}: {error}" => "Error al analizar el cumpleaños {bday}: {error}",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Algunos contactos están marcados para su eliminación, pero no eliminados todavía. Por favor, espere a que sean eliminados.",
"Click to undo deletion of {num} contacts" => "Pulse para deshacer la eliminación de {num} contactos",
"Cancelled deletion of {num} contacts" => "Cancelada la eliminación de {num} contactos",
"Add" => "Añadir",
"Contact is already in this group." => "El contacto ya se encuentra en este grupo.",
"Contacts are already in this group." => "Los contactos ya se encuentran es este grupo.",
"Couldn't get contact list." => "No se pudo obtener la lista de contactos.",
"Contact is not in this group." => "El contacto no se encuentra en este grupo.",
"Contacts are not in this group." => "Los contactos no se encuentran en este grupo.",
"Failed renaming group: {error}" => "Error renombrando el grupo: {error}",
"A group named {group} already exists" => "Ya existe un grupo llamado {group}",
"You can drag groups to\narrange them as you like." => "Puedes arrastrar grupos para\ncolocarlos como usted quiera.",
"Failed adding group: {error}" => "Error añadiendo el grupo: {error}",
"All" => "Todos",
"Favorites" => "Favoritos",
"Shared by {owner}" => "Compartido por {owner}",
"Not grouped" => "No agrupado",
"Failed loading groups: {error}" => "Error cargando grupos: {error} ",
"Please choose the addressbook" => "Por favor, escoja una libreta de direcciones",
"Import into..." => "Importando en...",
"Error loading import template" => "Error cargando la plantilla a importar",
"Import contacts" => "Importar contactos",
"Import" => "Importar",
"Import done" => "Importación realizada",
"Close" => "Cerrar",
"Error" => "Error",
"Displayname cannot be empty." => "El nombre para mostrar no puede estar vacío.",
"Show CardDav link" => "Mostrar enlace CardDav",
"Show read-only VCF link" => "Mostrar enlace VCF de sólo lectura",
"Download" => "Descargar",
"Edit" => "Editar",
"Delete" => "Eliminar",
"More..." => "Más...",
"Less..." => "Menos...",
"Server error! Please inform system administator" => "Error en el servidor. Por favor, informe al administrador.",
"Failed loading photo: {error}" => "Error cargando foto: {error}",
"You do not have permissions to see this contacts" => "No tiene permisos para ver este contacto",
"Contact not found" => "Contacto no encontrado",
"You do not have permissions to see these contacts" => "No tiene permisos para ver estos contactos",
"You do not have permissions add contacts to the address book" => "No tiene permisos para agregar contactos a esta libreta de direcciones",
"The backend for this address book does not support adding contacts" => "El backend de esta libreta de direcciones no permite agregar contactos",
"You do not have permissions to delete this contact" => "No tiene permisos para borrar este contacto",
"The backend for this address book does not support deleting contacts" => "El backend de esta libreta de direcciones no permite eliminar contactos",
"Unknown error" => "Error desconocido",
"The backend for this address book does not support updating" => "El backend de esta libreta de direcciones no permite actualizaciones",
"You don't have permissions to update the address book." => "No tiene permisos para modificar esta libreta de direcciones",
"You don't have permissions to delete the address book." => "No tiene permisos para borrar esta libreta de direcciones.",
"Address book not found" => "No se encontraron libretas de direcciones.",
"You do not have permissions to see this contact" => "No tiene permisos para ver este contacto",
"You do not have permissions to update this contact" => "No tiene permisos para actualizar este contacto",
"The backend for this contact does not support updating it" => "El backend de este contacto no permite actualizarlo",
"This backend not support adding contacts" => "Este backend no permite agregar contactos",
"Property not found" => "Propiedad no encontrada",
" Missing IM parameter for: " => "Falta el parámetro de IM para:",
"Unknown IM: " => "Servicio IM desconocido:",
"{name}'s Birthday" => "Cumpleaños de {name}",
"Error creating address book" => "Error creando libreta de direcciones",
"Error updating address book" => "Error actualizando libreta de direcciones",
"You do not have permissions to delete the \"%s\" address book" => "No tiene los permisos requeridos para eliminar la libreta de direcciones \"%s\"",
"Error deleting address book" => "Error borrando libreta de direcciones",
"Error creating contact." => "Error creando contacto.",
"Error deleting contact." => "Error borrando contacto.",
"Error retrieving contact." => "Error obteniendo contacto.",
"Error saving contact." => "Error guardando el contacto.",
"Error removing contact from other address book." => "Error borrando contacto desde otra libreta de direcciones.",
"Couldn't find contact." => " No se puede encontrar contacto.",
"No contact data in request." => "No hay información de contacto en la solicitud.",
"Error merging into contact." => "Error fusionando en contacto.",
"Error saving contact to backend." => "Error guardando contacto en backend.",
"Property name is not set." => "Nombre de propiedad no definido.",
"Property checksum is not set." => "Verificación de propiedad no definida.",
"Information about vCard is incorrect. Please reload the page." => "La información sobre el vCard es incorrecta. Por favor, recargue la página.",
"Error updating contact" => "Error actualizando contacto",
"Error saving contact to backend" => "Error guardando el contacto",
"Error getting user photo" => "Error obteniendo la imagen de usuario",
"No file was uploaded. Unknown error" => "No se subió ningún archivo. Error desconocido",
"There is no error, the file uploaded with success" => "No hay ningún error, el archivo se ha subido con éxito",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "El archivo subido sobrepasa la directiva \"upload_max_filesize\" del archivo PHP.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "El archivo subido sobrepasa la directiva \"MAX_FILE_SIZE\" especificada en el formulario HTML",
"The uploaded file was only partially uploaded" => "El archivo ha sido subido parcialmente",
"No file was uploaded" => "No se subió ningún archivo",
"Missing a temporary folder" => "Falta una carpeta temporal",
"Couldn't load temporary image: " => "No se pudo cargar la imagen temporal:",
"Couldn't save temporary image: " => "No se pudo guardar una imagen temporal",
"No photo path was submitted." => "No se ha introducido la ruta de la foto.",
"File doesn't exist:" => "El archivo no existe:",
"Error loading image." => "Error cargando la imagen.",
"Image has been removed from cache" => "La imagen ha sido eliminada de la caché",
"Error creating temporary image" => "Error creando la imagen temporal",
"Error cropping image" => "Error al recortar la imagen",
"Error resizing image" => "Error redimensionando la imagen.",
"Error getting PHOTO property." => "Error obteniendo las propiedades de la foto.",
"No group name given." => "No se ha especificado un nombre de grupo.",
"Error adding group." => "Error añadiendo el grupo.",
"No group name to rename from given." => "No hay nombre de grupo para renombrar el que se ha dado.",
"No group name to rename to given." => "No se ha especificado un nombre de grupo para renombrar el que se ha dado",
"Error renaming group." => "Error renombrando grupo.",
"Group ID missing from request." => "Falta el ID de grupo en la solicitud.",
"Group name missing from request." => "Falta el nombre del grupo en la petición.",
"Contact ID missing from request." => "Falta el ID de contacto en la solicitud.",
"Failed to write to disk" => "Error al escribir al disco",
"Not enough storage available" => "No hay suficiente espacio disponible",
"Attempt to upload blacklisted file:" => "Intentó subir un fichero en lista negra:",
"Error uploading contacts to storage." => "Error subiendo contactos al almacenamiento.",
"Error moving file to imports folder." => "Error moviendo ficheros a la carpeta de importaciones.",
"You do not have permissions to import into this address book." => "No tiene permiso para importar en esta libreta de direcciones.",
"File name missing from request." => "Falta el nombre del fichero en la petición.",
"Progress key missing from request." => "Falta la clave de progreso en la petición.",
"Attempt to access blacklisted file:" => "Intentó acceder a un fichero en la lista negra:",
"No contacts found in: " => "No se encontraron contactos en:",
"No key is given." => "No se ha especificado una clave.",
"No value is given." => "No se ha especificado un valor.",
"Could not set preference: " => "No se pudo establecer la opción:",
"Contact" => "Contacto",
"Other" => "Otro",
"HomePage" => "Página de inicio",
"Jabber" => "Jabber",
"Internet call" => "Llamada por Internet",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "Google Talk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"Work" => "Trabajo",
"Home" => "Particular",
"Mobile" => "Móvil",
"Text" => "Texto",
"Voice" => "Voz",
"Message" => "Mensaje",
"Fax" => "Fax",
"Video" => "Vídeo",
"Pager" => "Localizador",
"Internet" => "Internet",
"Friends" => "Amigos",
"Family" => "Familia",
"New Contact" => "Nuevo contacto",
"Group name" => "Nombre de grupo",
"New Group" => "Nuevo grupo",
"Address books" => "Libretas de direcciones",
"Display name" => "Nombre para mostrar",
"Add Address Book" => "Añadir libreta de direcciones",
"Select file..." => "Seleccionar archivo",
"(De-)select all" => "(De-)seleccionar todos",
"Sort order" => "Ordenar",
"First- Lastname" => "Nombre, Apellido",
"Last-, Firstname" => "Apellido, Nombre",
"Groups" => "Grupos",
"Favorite" => "Favorito",
"Merge selected" => "Combinar seleccionados",
"Keyboard shortcuts" => "Atajos de teclado",
"Navigation" => "Navegación",
"Next contact in list" => "Siguiente contacto en la lista",
"Previous contact in list" => "Anterior contacto en la lista",
"Expand/collapse current addressbook" => "Abrir/cerrar la libreta actual",
"Next addressbook" => "Siguiente libreta de direcciones",
"Previous addressbook" => "Anterior libreta de direcciones",
"Actions" => "Acciones",
"Refresh contacts list" => "Refrescar la lista de contactos",
"Add new contact" => "Añadir un nuevo contacto",
"Add new addressbook" => "Añadir nueva libreta de direcciones",
"Delete current contact" => "Eliminar contacto actual",
"<h3>You have no contacts in your address book or your address book is disabled.</h3><p>Add a new contact or import existing contacts from a VCF file.</p>" => "<h3>No tiene contactos en su libreta de direcciones o su libreta de direcciones está desactivada.</h3><p>Agregue un nuevo contacto o importe contactos de un archivo VCF.</p>",
"Add contact" => "Añadir contacto",
"Delete group" => "Eliminar grupo",
"Rename group" => "Renombrar grupo",
"Which contact should the data be merged into?" => "¿En qué contacto deben fusionarse los datos?",
"Delete the other(s) after successful merge?" => "¿Borrar el/los otro(s) después de una combinación satisfactoria?",
"Compose mail" => "Redactar mensaje",
"Delete current photo" => "Eliminar fotografía actual",
"Edit current photo" => "Editar fotografía actual",
"Upload new photo" => "Subir nueva fotografía",
"Select photo from ownCloud" => "Seleccionar fotografía desde ownCloud",
"Name" => "Nombre",
"First name" => "Nombre",
"Additional names" => "Nombres adicionales",
"Last name" => "Apellido",
"Select groups" => "Seleccionar grupos",
"Select address book" => "Seleccionar libreta de direcciones",
"Nickname" => "Alias",
"Enter nickname" => "Introduce un alias",
"Title" => "Título",
"Enter title" => "Introduzca título",
"Organization" => "Organización",
"Enter organization" => "Introduzca organización",
"Birthday" => "Fecha de nacimiento",
"Notes go here..." => "Puede escribir notas aquí...",
"Export as VCF" => "Exportar como VCF",
"Add field..." => "Agregar campo...",
"Phone" => "Teléfono",
"Email" => "E-mail",
"Instant Messaging" => "Mensajería instantánea",
"Address" => "Dirección",
"Note" => "Nota",
"Web site" => "Sitio Web",
"Delete contact" => "Eliminar contacto",
"Preferred" => "Preferido",
"Please specify a valid email address." => "Por favor especifica una dirección de correo electrónico válida.",
"someone@example.com" => "alguien@ejemplo.com",
"Mail to address" => "Enviar por correo a la dirección",
"Delete email address" => "Eliminar dirección de correo electrónico",
"Enter phone number" => "Introduce un número de teléfono",
"Delete phone number" => "Eliminar número de teléfono",
"Go to web site" => "Ir al sitio Web",
"Delete URL" => "Eliminar URL",
"View on map" => "Ver en el mapa",
"Delete address" => "Eliminar dirección",
"1600 Pennsylvania Avenue, NW" => "1600 Pennsylvania Avenue, NW",
"Street address" => "Calle",
"20500" => "20500",
"Postal code" => "Código postal",
"Washington, DC" => "Washington, DC",
"City" => "Ciudad",
"District of Columbia" => "District of Columbia",
"State or province" => "Estado o provincia",
"USA" => "EUA",
"Country" => "País",
"Instant Messenger" => "Mensajero instantáneo",
"Delete IM" => "Eliminar IM",
"Active" => "Activo",
"Share" => "Compartir",
"Export" => "Exportar",
"CardDAV link" => "Enlace CardDav",
"CardDAV syncing addresses" => "Sincronizando direcciones",
"more info" => "Más información",
"Primary address (Kontact et al)" => "Dirección principal (Kontact y otros)",
"iOS/OS X" => "iOS/OS X",
"Addressbooks" => "Libretas de direcciones",
"New Address Book" => "Nueva libreta de direcciones",
"Description" => "Descripción"
);

==> owncloud_7.0.0~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/contacts/l10n/es.php <==
<?php $TRANSLATIONS = array(
"Contacts" => "Contactos",
"Add new LDAP Addressbook" => "Agregar nueva libreta de direcciones LDAP",
"Ok" => "Aceptar",
"Cancel" => "Cancelar",
"Save" => "Guardar",
"Edit Addressbook" => "Editar libreta de direcciones",
"Starting file import" => "Iniciando importación de archivos",
"Format selected: {format}" => "Formato seleccionado: {format}",
"Automatic format detection" => "Detección automática de formato",
"Processing {count}/{total} cards" => "Procesando {count}/{total} tarjetas",
"Total:{total}, Success:{imported}, Errors:{failed}" => "Total:{total}, exitosas:{imported}, errores:{failed}",
"An address book called {name} already exists" => "Ya existe una libreta de contactos llamada {name}",
"Failed adding address book: {error}" => "Hubo un fallo al agregar la libreta de contactos: {error}",
"Failed loading address books: {error}" => "Se produjo un error al cargar las libretas de contactos: {error}",
"Server error! Please inform system administator" => "Error en el servidor. Por favor, informe al administrador.",
"Indexing contacts" => "Indexando contactos",
"Unrecoverable error loading address books: {msg}" => "Error irrecuperable mientras se cargaban las libretas de contactos: {msg}",
"Error." => "Error.",
"Add to..." => "Añadir a...",
"Remove from..." => "Eliminar de...",
"Add group..." => "Añadir grupo...",
"Invalid URL: \"{url}\"" => "URL no válida: \"{url}\"",
"Invalid email: \"{url}\"" => "Dirección de correo inválida: \"{url}\"",
"Merge failed. Cannot find contact: {id}" => "Error en la combinación. No se puede encontrar contacto: {id}",
"Merge failed." => "Error en la combinación.",
"Merge failed. Error saving contact." => "Combinación fallida. Error guardando el contacto.",
"Select photo" => "Seleccionar una foto",
"Network or server error. Please inform administrator." => "Error en la red o en el servidor. Por favor, informe al administrador.",
"Only images can be used as contact photos" => "Solo imágenes pueden ser usadas como fotos de contactos",
"The size of \"{filename}\" exceeds the maximum allowed {size}" => "El tamaño de \"{filename}\" excede el máximo permitido {size}",
"Error adding to group." => "Error añadiendo al grupo.",
"Error removing from group." => "Error eliminando del grupo.",
"You have selected over 300 contacts.\nThis will most likely fail! Click here to try anyway." => "Ha seleccionado más de 300 contactos.\n¡Puede que no tenga éxito! Pulse aquí para intentarlo de todas formas.",
"Error setting {name} as favorite." => "Error configurando {name} como favorito.",
"Merge contacts" => "Combinar contactos",
"Add group" => "Añadir grupo",
"OK" => "Aceptar",
"Could not find contact: {id}" => "No se puede encontrar el contacto: {id}",
"Edit profile picture" => "Editar imagen de perfil.",
"Crop photo" => "Recortar imagen",
"Error parsing date: {date}" => "Error al analizar la fecha: {date}",
"# groups" => "# grupos",
"Error parsing birthday {bday}" => "Error al analizar la fecha de nacimiento {bday}",
"The backend does not support multi-byte characters." => "El backend no Soporta caracteres multi-byte.",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Algunos contactos están marcados para su eliminación, pero no eliminados todavía. Por favor, espere a que sean eliminados.",
"Click to undo deletion of {num} contacts" => "Pulse para deshacer la eliminación de {num} contactos",
"Cancelled deletion of {num} contacts" => "Cancelada la eliminación de {num} contactos",
"Add" => "Añadir",
"Contact is already in this group." => "El contacto ya se encuentra en este grupo.",
"Contacts are already in this group." => "Los contactos ya se encuentran es este grupo.",
"Couldn't get contact list." => "No se pudo obtener la lista de contactos.",
"Contact is not in this group." => "El contacto no se encuentra en este grupo.",
"Contacts are not in this group." => "Los contactos no se encuentran en este grupo.",
"A group named \"{group}\" already exists" => "Ya existe un grupo llamado \"{group}\"",
"Failed renaming group: {error}" => "Error renombrando el grupo: {error}",
"You can drag groups to\narrange them as you like." => "Puedes arrastrar grupos para\ncolocarlos como usted quiera.",
"Failed adding group: {error}" => "Error añadiendo el grupo: {error}",
"All" => "Todos",
"Favorites" => "Favoritos",
"Shared by {owner}" => "Compartido por {owner}",
"Not grouped" => "No agrupado",
"Failed loading groups: {error}" => "Error cargando grupos: {error} ",
"Please choose the addressbook" => "Por favor, escoja una libreta de direcciones",
"Import into..." => "Importando en...",
"Error loading import template" => "Error cargando la plantilla a importar",
"Import contacts" => "Importar contactos",
"Import" => "Importar",
"Importing..." => "Importando...",
"Import done" => "Importación realizada",
"Close" => "Cerrar",
"Error, missing parameters: " => "Error, parámetros faltantes:",
"Failed loading photo: {error}" => "Error cargando foto: {error}",
"You do not have permissions to see this contact" => "No tiene permisos para ver este contacto",
"Contact not found" => "Contacto no encontrado",
"You do not have permissions to see these contacts" => "No tiene permisos para ver estos contactos",
"You do not have permissions add contacts to the address book" => "No tiene permisos para agregar contactos a esta libreta de direcciones",
"The backend for this address book does not support adding contacts" => "El backend de esta libreta de direcciones no permite agregar contactos",
"You do not have permissions to delete this contact" => "No tiene permisos para borrar este contacto",
"The backend for this address book does not support deleting contacts" => "El backend de esta libreta de direcciones no permite eliminar contactos",
"Unknown error" => "Error desconocido",
"Access denied" => "Acceso denegado",
"The backend for this address book does not support updating" => "El backend de esta libreta de direcciones no permite actualizaciones",
"You don't have permissions to delete the address book." => "No tiene permisos para borrar esta libreta de direcciones.",
"Address book not found" => "No se encontraron libretas de direcciones.",
"You do not have permissions to update this contact" => "No tiene permisos para actualizar este contacto",
"The backend for this contact does not support updating it" => "El backend de este contacto no permite actualizarlo",
"This backend does not support adding contacts" => "Este backend no permite agregar contactos",
"Property not found" => "Propiedad no encontrada",
" Missing IM parameter for: " => "Falta el parámetro de IM para:",
"Unknown IM: " => "Servicio IM desconocido:",
"{name}'s Birthday" => "Cumpleaños de {name}",
"Error creating address book" => "Error creando libreta de direcciones",
"The \"%s\" backend does not support deleting address books" => "El backend \"%s\" no Soporta eliminacion de libretas de direcciones",
"You do not have permissions to delete the \"%s\" address book" => "No tiene los permisos requeridos para eliminar la libreta de direcciones \"%s\"",
"Error deleting address book" => "Error borrando libreta de direcciones",
"Error creating contact." => "Error creando contacto.",
"Error creating contact" => "Error al crear contacto",
"Error deleting contact" => "Error al eliminar contacto",
"Error retrieving contact" => "Error al recuperar contacto",
"Error saving contact" => "Error al guardar contacto",
"Error removing contact from other address book." => "Error borrando contacto desde otra libreta de direcciones.",
"Error getting moved contact" => "Error al obtener contacto movido",
"Couldn't find contact." => " No se puede encontrar contacto.",
"No contact data in request." => "No hay información de contacto en la solicitud.",
"Error merging into contact." => "Error fusionando en contacto.",
"Error saving contact to backend." => "Error guardando contacto en backend.",
"Property name is not set." => "Nombre de propiedad no definido.",
"Property checksum is not set." => "Verificación de propiedad no definida.",
"Information about vCard is incorrect. Please reload the page." => "La información sobre el vCard es incorrecta. Por favor, recargue la página.",
"Error updating contact" => "Error actualizando contacto",
"Error saving contact to backend" => "Error guardando el contacto",
"Error getting user photo" => "Error obteniendo la imagen de usuario",
"No photo path was submitted." => "No se ha introducido la ruta de la foto.",
"Error loading image from cache" => "Error al cargar imagen de la memoria caché",
"Error getting PHOTO property." => "Error obteniendo las propiedades de la foto.",
"Error saving contact." => "Error guardando el contacto.",
"No group name given." => "No se ha especificado un nombre de grupo.",
"Error adding group." => "Error añadiendo el grupo.",
"No group name to rename from given." => "No hay nombre de grupo para renombrar el que se ha dado.",
"No group name to rename to given." => "No se ha especificado un nombre de grupo para renombrar el que se ha dado",
"Error renaming group." => "Error renombrando grupo.",
"Group ID missing from request." => "Falta el ID de grupo en la solicitud.",
"Group name missing from request." => "Falta el nombre del grupo en la petición.",
"Contact ID missing from request." => "Falta el ID de contacto en la solicitud.",
"No file was uploaded. Unknown error" => "No se subió ningún archivo. Error desconocido",
"There is no error, the file uploaded with success" => "No hay ningún error, el archivo se ha subido con éxito",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "El archivo subido sobrepasa la directiva \"upload_max_filesize\" del archivo PHP.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "El archivo subido sobrepasa la directiva \"MAX_FILE_SIZE\" especificada en el formulario HTML",
"The uploaded file was only partially uploaded" => "El archivo ha sido subido parcialmente",
"No file was uploaded" => "No se subió ningún archivo",
"Missing a temporary folder" => "Falta una carpeta temporal",
"Failed to write to disk" => "Error al escribir al disco",
"Not enough storage available" => "No hay suficiente espacio disponible",
"Attempt to upload blacklisted file:" => "Intentó subir un fichero en lista negra:",
"Error uploading contacts to storage." => "Error subiendo contactos al almacenamiento.",
"Error moving file to imports folder." => "Error moviendo ficheros a la carpeta de importaciones.",
"You do not have permissions to import into this address book." => "No tiene permiso para importar en esta libreta de direcciones.",
"File name missing from request." => "Falta el nombre del fichero en la petición.",
"Progress key missing from request." => "Falta la clave de progreso en la petición.",
"Attempt to access blacklisted file:" => "Intentó acceder a un fichero en la lista negra:",
"No key is given." => "No se ha especificado una clave.",
"No value is given." => "No se ha especificado un valor.",
"Could not set preference: " => "No se pudo establecer la opción:",
"Contact" => "Contacto",
"Other" => "Otro",
"HomePage" => "Página de inicio",
"Jabber" => "Jabber",
"Internet call" => "Llamada por Internet",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "Google Talk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"ownCloud" => "ownCloud",
"Work" => "Trabajo",
"Home" => "Particular",
"Mobile" => "Móvil",
"Text" => "Texto",
"Voice" => "Voz",
"Message" => "Mensaje",
"Fax" => "Fax",
"Video" => "Vídeo",
"Pager" => "Localizador",
"Internet" => "Internet",
"Friends" => "Amigos",
"Family" => "Familia",
"Enable LDAP Backend" => "Habilitar backend de LDAP",
"Enable LDAP backend for the contacts application" => "Habilitar backend de LDAP para la aplicación de contactos",
"Warning: LDAP Backend is in beta mode, use with precautions" => "Advertencia: el backend de LDAP está en modo beta, usar con precaución",
"New contact" => "Nuevo contacto",
"Group name" => "Nombre de grupo",
"New group" => "Nuevo grupo",
"Address books" => "Libretas de direcciones",
"Display name" => "Nombre para mostrar",
"Add Address Book" => "Añadir libreta de direcciones",
"Add LDAP Address Book" => "Agregar libreta de direcciones LDAP",
"Automatic format" => "Formato detectado automáticamente",
"Select file..." => "Seleccionar archivo",
"(De-)select all" => "(De-)seleccionar todos",
"Sort order" => "Ordenar",
"First- Lastname" => "Nombre, Apellido",
"Last-, Firstname" => "Apellido, Nombre",
"Delete" => "Eliminar",
"Groups" => "Grupos",
"Download" => "Descargar",
"Merge" => "Unir",
"Email" => "E-mail",
"Phone" => "Teléfono",
"Address" => "Dirección",
"Group" => "Grupo",
"Keyboard shortcuts" => "Atajos de teclado",
"Navigation" => "Navegación",
"Next contact in list" => "Siguiente contacto en la lista",
"Previous contact in list" => "Anterior contacto en la lista",
"Expand/collapse current addressbook" => "Abrir/cerrar la libreta actual",
"Next addressbook" => "Siguiente libreta de direcciones",
"Previous addressbook" => "Anterior libreta de direcciones",
"Actions" => "Acciones",
"Refresh contacts list" => "Refrescar la lista de contactos",
"Add new contact" => "Añadir un nuevo contacto",
"Add new addressbook" => "Añadir nueva libreta de direcciones",
"Delete current contact" => "Eliminar contacto actual",
"You have no contacts in your address book or your address book is disabled." => "No tiene contactos en su libreta de direcciones, o su libreta está desactivada.",
"Add a new contact or import existing contacts from a VCF file." => "Agregue un nuevo contacto o importe contactos existentes de un archivo VCF.",
"Which contact should the data be merged into?" => "¿En qué contacto deben fusionarse los datos?",
"Delete the other(s) after successful merge?" => "¿Borrar el/los otro(s) después de una combinación satisfactoria?",
"Compose mail" => "Redactar mensaje",
"Delete current photo" => "Eliminar fotografía actual",
"Edit current photo" => "Editar fotografía actual",
"Upload new photo" => "Subir nueva fotografía",
"Select photo from Files" => "Seleccionar foto desde Archivos",
"Favorite" => "Favorito",
"Name" => "Nombre",
"First name" => "Nombre",
"Additional names" => "Nombres adicionales",
"Last name" => "Apellido",
"Address book" => "Libreta de direcciones",
"Nickname" => "Alias",
"Title" => "Título",
"Organization" => "Organización",
"Birthday" => "Fecha de nacimiento",
"Website" => "Sitio web",
"Instant messaging" => "Mensajería instantánea",
"Notes go here..." => "Puede escribir notas aquí...",
"Add field..." => "Agregar campo...",
"Instant Messaging" => "Mensajería instantánea",
"Note" => "Nota",
"Web site" => "Sitio Web",
"Preferred" => "Preferido",
"Please specify a valid email address." => "Por favor especifica una dirección de correo electrónico válida.",
"someone@example.com" => "alguien@ejemplo.com",
"Mail to address" => "Enviar por correo a la dirección",
"Delete email address" => "Eliminar dirección de correo electrónico",
"Enter phone number" => "Introduce un número de teléfono",
"Go to web site" => "Ir al sitio Web",
"View on map" => "Ver en el mapa",
"Street address" => "Calle",
"Postal code" => "Código postal",
"City" => "Ciudad",
"State or province" => "Estado o provincia",
"Country" => "País",
"Instant Messenger" => "Mensajero instantáneo",
"Active" => "Activo",
"Share" => "Compartir",
"Export" => "Exportar",
"CardDAV link" => "Enlace CardDav",
"Edit" => "Editar",
"Addressbook URI" => "URI de la libreta de direcciones",
"URI" => "URI",
"Description" => "Descripción",
"LDAP URL" => "URL de LDAP",
"Anonymous" => "Anónimo",
"Read-only" => "Solo-lectura",
"Read-Only" => "Solo-lectura",
"User" => "Usuario",
"Password" => "Contraseña",
"Page size" => "Tamaño de página",
"Base DN for search" => "Nombre Distinguido (DN) base para búsqueda",
"Base DN" => "DN base",
"Search filter" => "Filtro de búsqueda",
"Filter" => "Filtro",
"Base DN for modification" => "Nombre Distinguido (DN) base para modificación",
"Base DN modification" => "DN base modificación",
"Connector" => "Conector",
"Connector value (Better use external editor and copy/paste)" => "Valor del conector (mejor usar un editor externo y copiar/pegar)",
"Copy from (Warning, replaces current custom value)" => "Copiar de (advertencia: reemplaza el valor actual)"
);
